---
hide:
  - navigation
---

<!--
  - Licensed to the Apache Software Foundation (ASF) under one
  - or more contributor license agreements.  See the NOTICE file
  - distributed with this work for additional information
  - regarding copyright ownership.  The ASF licenses this file
  - to you under the Apache License, Version 2.0 (the
  - "License"); you may not use this file except in compliance
  - with the License.  You may obtain a copy of the License at
  -
  -   http://www.apache.org/licenses/LICENSE-2.0
  -
  - Unless required by applicable law or agreed to in writing,
  - software distributed under the License is distributed on an
  - "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  - KIND, either express or implied.  See the License for the
  - specific language governing permissions and limitations
  - under the License.
  -->

# Join the community

Apache Iceberg tracks issues in GitHub and prefers to receive contributions as pull requests.

Community discussions happen primarily on the [dev mailing list](https://lists.apache.org/list.html?dev@iceberg.apache.org), on [Apache Iceberg Slack workspace](https://join.slack.com/t/apache-iceberg/shared_invite/zt-287g3akar-K9Oe_En5j1UL7Y_Ikpai3A) in the #python channel, and on specific [GitHub issues](https://github.com/apache/iceberg-python/issues).

## Iceberg Community Events

The PyIceberg community sync is on the last Tuesday of every month. The calendar event is located on the [Iceberg Dev Events](https://iceberg.apache.org/community#iceberg-community-events) calendar.

## Community Guidelines

### Apache Iceberg Community Guidelines

The Apache Iceberg community is built on the principles described in the [Apache Way](https://www.apache.org/theapacheway/index.html)
and all who engage with the community are expected to be respectful, open, come with the best interests of the community in mind,
and abide by the Apache Foundation [Code of Conduct](https://www.apache.org/foundation/policies/conduct.html).

### Participants with Corporate Interests

A wide range of corporate entities have interests that overlap in both features and frameworks related to Iceberg and while we
encourage engagement and contributions, the community is not a venue for marketing, solicitation, or recruitment.

Any vendor who wants to participate in the Apache Iceberg community Slack workspace should create a dedicated vendor channel
for their organization prefixed by `vendor-`.

This space can be used to discuss features and integration with Iceberg related to the vendor offering.  This space should not
be used to promote competing vendor products/services or disparage other vendor offerings.  Discussion should be focused on
questions asked by the community and not to expand/introduce/redirect users to alternate offerings.

### Marketing / Solicitation / Recruiting

The Apache Iceberg community is a space for everyone to operate free of influence. The development lists, Slack workspace,
and GitHub should not be used to market products or services.  Solicitation or overt promotion should not be performed in common
channels or through direct messages.

Recruitment of community members should not be conducted through direct messages or community channels, but opportunities
related to contributing to or using Iceberg can be posted to the `#jobs` channel.

For questions regarding any of the guidelines above, please contact a PMC member
